/*
 * Test Low Power Modes for STM32F0xx
 * Tested in my custom PCB using a STM32F030F4P6
 */

#include "Arduino.h"
#include <stdio.h>

#include "stm32F0_Sleep.h"
LowPowerMode LowPowerMode;

#define LED_Pin PA4


/*
 * Set Pins to Analog INPUT to decrease power usage
 */
void setPinsToAnalog(){
	pinMode(PA0, INPUT_ANALOG);
	pinMode(PA1, INPUT_ANALOG);
	pinMode(PA2, INPUT_ANALOG);
	pinMode(PA3, INPUT_ANALOG);
	pinMode(PA4, INPUT_ANALOG);
	pinMode(PA5, INPUT_ANALOG);
	pinMode(PA6, INPUT_ANALOG);
	pinMode(PA7, INPUT_ANALOG);
	
	pinMode(PA9, INPUT_ANALOG);
	pinMode(PA10, INPUT_ANALOG);
	
	pinMode(PB1, INPUT_ANALOG);
	
	pinMode(PF0, INPUT_ANALOG);
	pinMode(PF1, INPUT_ANALOG);
}


void setup(){
	
	//Turn ON the LED
	pinMode(LED_Pin, OUTPUT);
	digitalWrite_HIGH(LED_Pin);
	
	//Initialize the library
	LowPowerMode.init();

}

void loop(){
	
	//Just Keep the LED turned on to measure the running power
	delay(5000);
	togglePin(LED_Pin);
	
	//Set all the GPIOs to analog input to reduce power usage
	setPinsToAnalog();
	
	//LowPowerMode.stopRTCwakeup(0, 0 , 5);
	LowPowerMode.standbyRTCwakeup(0, 0, 5);
	//When wakeup from Standby with the RTC it will start the program from the begining.
}



/**
  * @brief  Main Function
  * @param  None
  * @retval None
  */

int main(void)
{
	InternalClocks_Init(); //Set the internal clock @ 8MHz
    Delay_Init();
    setup();
    for(;;)loop();
}